@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-from objutils import loads, dumps
 import unittest
 
+from objutils import dumps
+from objutils import loads
+
 
 MOSTEC = b""";10B000576F77212044696420796F75207265610624
 ;10B0106C6C7920676F207468726F756768206106B9
@@ -19,18 +20,16 @@ S5030004F8"""
 
 
 class TestRoundtrip(unittest.TestCase):
-
     def testLoadsWorks(self):
         data = loads("mostec", MOSTEC)
-        #data.hexdump()
-        #print(dumps("srec", data))
-        self.assertEqual(dumps("srec", data, s5record = True), S19)
+        # data.hexdump()
+        # print(dumps("srec", data))
+        self.assertEqual(dumps("srec", data, s5record=True), S19)
 
     def testDumpsWorks(self):
         data = loads("srec", S19)
         self.assertEqual(dumps("mostec", data), MOSTEC)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
-
